@@ -7,6 +7,7 @@ from typing import Optional
 
 import gitlab
 import requests
+from requests.auth import AuthBase
 
 from .errors import ImproperConfigurationError
 from .helpers import LoggedFunction
@@ -59,6 +60,29 @@ def _fix_mime_types():
     mimetypes.add_type("text/markdown", ".md")
 
 
+class TokenAuth(AuthBase):
+    """
+    requests Authentication for token based authorization
+    """
+
+    def __init__(self, token):
+        self.token = token
+
+    def __eq__(self, other):
+        return all(
+            [
+                self.token == getattr(other, "token", None),
+            ]
+        )
+
+    def __ne__(self, other):
+        return not self == other
+
+    def __call__(self, r):
+        r.headers["Authorization"] = f"token {self.token}"
+        return r
+
+
 class Github(Base):
     """Github helper class"""
 
@@ -81,6 +105,17 @@ class Github(Base):
         """
         return os.environ.get("GH_TOKEN")
 
+    @staticmethod
+    def auth() -> Optional[TokenAuth]:
+        """Github token property
+
+        :return: The Github token environment variable (GH_TOKEN) value
+        """
+        token = Github.token()
+        if not token:
+            return None
+        return TokenAuth(token)
+
     @staticmethod
     @LoggedFunction(logger)
     def check_build_status(owner: str, repo: str, ref: str) -> bool:
@@ -94,10 +129,8 @@ class Github(Base):
 
         :return: Was the build status success?
         """
-        url = "{domain}/repos/{owner}/{repo}/commits/{ref}/status"
-        response = requests.get(
-            url.format(domain=Github.API_URL, owner=owner, repo=repo, ref=ref)
-        )
+        url = f"{Github.API_URL}/repos/{owner}/{repo}/commits/{ref}/status"
+        response = requests.get(url)
         return response.json()["state"] == "success"
 
     @classmethod
@@ -123,7 +156,7 @@ class Github(Base):
                 "draft": False,
                 "prerelease": False,
             },
-            headers={"Authorization": "token {}".format(Github.token())},
+            auth=Github.auth(),
         )
         logger.debug(f"Release creation status code: {response.status_code}")
 
@@ -144,7 +177,7 @@ class Github(Base):
         """
         response = requests.get(
             f"{Github.API_URL}/repos/{owner}/{repo}/releases/tags/{tag}",
-            headers={"Authorization": "token {}".format(Github.token())},
+            auth=Github.auth(),
         )
         logger.debug(f"Get release by tag status code: {response.status_code}")
 
@@ -167,7 +200,7 @@ class Github(Base):
         response = requests.post(
             f"{Github.API_URL}/repos/{owner}/{repo}/releases/{id}",
             json={"body": changelog},
-            headers={"Authorization": "token {}".format(Github.token())},
+            auth=Github.auth(),
         )
         logger.debug(f"Edit release status code: {response.status_code}")
 
@@ -216,24 +249,32 @@ class Github(Base):
 
         :return: The status of the request
         """
-        url = "https://uploads.github.com/repos/{owner}/{repo}/releases/{id}/assets"
+        url = f"https://uploads.github.com/repos/{owner}/{repo}/releases/{release_id}/assets"
+
+        content_type = mimetypes.guess_type(file, strict=False)[0]
+        if not content_type:
+            content_type = "application/octet-stream"
 
         response = requests.post(
-            url.format(owner=owner, repo=repo, id=release_id),
+            url,
             params={"name": os.path.basename(file), "label": label},
             headers={
-                "Authorization": "token {}".format(Github.token()),
-                "Content-Type": mimetypes.guess_type(file, strict=False)[0],
+                "Content-Type": content_type,
             },
+            auth=Github.auth(),
             data=open(file, "rb").read(),
         )
         logger.debug(
-            "Asset upload completed, url: {}, status code: {}".format(
-                response.url, response.status_code
-            )
+            f"Asset upload completed, url: {response.url}, status code: {response.status_code}"
         )
         logger.debug(response.json())
-        return response.status_code == 201
+
+        try:
+            response.raise_for_status()
+            return True
+        except requests.exceptions.HTTPError as e:
+            logger.warning(f"The github file upload {file} has failed: {e}")
+            return False
 
     @classmethod
     def upload_dists(cls, owner: str, repo: str, version: str, path: str) -> bool:
@@ -303,15 +344,11 @@ class Gitlab(Base):
             if job["status"] not in ["success", "skipped"]:
                 if job["status"] == "pending":
                     logger.debug(
-                        "check_build_status: job {} is still in pending status".format(
-                            job["name"]
-                        )
+                        f"check_build_status: job {job['name']} is still in pending status"
                     )
                     return False
                 elif job["status"] == "failed" and not job["allow_failure"]:
-                    logger.debug(
-                        "check_build_status: job {} failed".format(job["name"])
-                    )
+                    logger.debug(f"check_build_status: job {job['name']} failed")
                     return False
         return True
 
@@ -336,14 +373,10 @@ class Gitlab(Base):
             tag = gl.projects.get(owner + "/" + repo).tags.get(ref)
             tag.set_release_description(changelog)
         except gitlab.exceptions.GitlabGetError:
-            logger.debug(
-                "Tag {} was not found for project {}".format(ref, owner + "/" + repo)
-            )
+            logger.debug(f"Tag {ref} was not found for project {owner}/{repo}")
             return False
         except gitlab.exceptions.GitlabUpdateError:
-            logger.debug(
-                "Failed to update tag {} for project {}".format(ref, owner + "/" + repo)
-            )
+            logger.debug(f"Failed to update tag {ref} for project {owner}/{repo}")
             return False
 
         return True
@@ -371,7 +404,7 @@ def check_build_status(owner: str, repository: str, ref: str) -> bool:
     :param ref: Commit or branch reference
     :return: A boolean with the build status
     """
-    logger.debug("check_build_status")
+    logger.debug(f"Checking build status for {owner}/{repository}#{ref}")
     return get_hvcs().check_build_status(owner, repository, ref)
 
 
@@ -385,11 +418,7 @@ def post_changelog(owner: str, repository: str, version: str, changelog: str) ->
     :param changelog: A string with the changelog in correct format
     :return: a tuple with success status and payload from hvcs
     """
-    logger.debug(
-        "post_changelog(owner={}, repository={}, version={})".format(
-            owner, repository, version
-        )
-    )
+    logger.debug(f"Posting release changelog for {owner}/{repository} {version}")
     return get_hvcs().post_release_changelog(owner, repository, version, changelog)
 
 
